require "import"
import "android.content.Context"
import "android.os.Vibrator"
import "android.media.ToneGenerator"
import "android.media.AudioManager"
import "android.widget.*"
import "com.androlua.*"
import "android.net.Uri"
import "android.content.Intent"
import "android.text.Html"
import "android.content.ClipboardManager"
import "android.content.ClipData"

local context = activity or service
local vibrator = context.getSystemService(Context.VIBRATOR_SERVICE)
vibrator.vibrate(40)

local languageCodes = {
    ["Hindi"] = "hi",
    ["English"] = "en",
    ["Indonesian"] = "id",
    ["Urdu"] = "ur",
    ["Marathi"] = "mr",
}

local languageList = {
    "Hindi",
    "English",
    "Indonesian",
    "Urdu",
    "Marathi",
}

local translationResult = ""

local function capitalizeFirstWord(str)
    return str:gsub("^%l", string.upper)
end

local function addPunctuation(str)
    return str .. "."
end

local function showTranslation(language, translation)
    service.speak("Translated text with content: " .. translation)
    vibrator.vibrate(100)
    service.setText(translation)
end

local layout = {
    GridView,
    id = "grid",
    numColumns = 1,
    layout_width = "fill",
    layout_height = "fill"
}

local dlg = LuaDialog(context)
dlg.View = loadlayout(layout)
grid.adapter = SingleLineAdapter(service, String(languageList))

dlg.setTitle("Alat Terjemahan Cepat 5 bahasa")
    .setButton("Keluar", nil)
    .show()

grid.onItemClick = function(l, v)
    dlg.dismiss()
    task(500, function()
        local language = v.text
        local defaultLanguage = Locale.getDefault().getLanguage()
        local languageCode = languageCodes[language]

        if languageCode then
            local url = "https://translate.google.com/m?sl=auto&hl=" .. defaultLanguage .. "&q=" .. Uri.encode(service.getText(node))
            url = url .. "&tl=" .. languageCode

            Http.get(url, function(status, result)
                if status == 200 then
                    local translation = tostring(Html.fromHtml(result:match('<div class="result%-container">([^<]+)</div>')))
                    translation = capitalizeFirstWord(translation)
                    translation = addPunctuation(translation)
                    translationResult = translationResult .. translation

                    showTranslation(language, translationResult)
                else
                    print("Sorry, an issue occurred.\nPossible solutions:\n- Ensure you are connected to the Internet.\n- Try to provide a stable internet connection.\nNote: Some elements, images, edit boxes, etc., may not be translatable.")
                    vibrator.vibrate(200)
                    service.playSoundTick()
                end
            end)
        else
            print("Language not supported.")
            vibrator.vibrate(200)
            service.playSoundClock()
        end
    end)
end